/* IMPORT */
/* MAIN */
class AbortSignal {
    constructor() {
        /* VARIABLES */
        this.aborted = false;
        this.listeners = {};
    }
    /* EVENTS API */
    addEventListener(event, listener) {
        const listeners = this.listeners[event] || (this.listeners[event] = []);
        listeners.push(listener);
    }
    removeEventListener(event, listener) {
        const listeners = this.listeners[event];
        if (!listeners)
            return;
        listeners.splice(listeners.indexOf(listener), 1);
    }
    dispatchEvent(event) {
        const listeners = this.listeners[event];
        if (!listeners)
            return true;
        listeners.slice().forEach(listener => listener());
        return true;
    }
    /* API */
    abort() {
        if (this.aborted)
            return;
        this.aborted = true;
        this.dispatchEvent('abort');
    }
}
/* EXPORT */
export default AbortSignal;
